@@ -2,14 +2,15 @@ from typing import Dict
 
 from vortex.Tuple import addTupleType, TupleField, Tuple
 
-from peek_abstract_chunked_index.private.tuples.ACIUpdateDateTupleABC import \
-    ACIUpdateDateTupleABC
+from peek_abstract_chunked_index.private.tuples.ACIUpdateDateTupleABC import (
+    ACIUpdateDateTupleABC,
+)
 from peek_core_search._private.PluginNames import searchTuplePrefix
 
 
 @addTupleType
 class SearchIndexUpdateDateTuple(Tuple, ACIUpdateDateTupleABC):
-    """ Search Index Update Date Tuple
+    """Search Index Update Date Tuple
 
     This tuple represents the state of the chunks in the cache.
     Each chunkKey has a lastUpdateDate as a string, this is used for offline caching
@@ -19,7 +20,7 @@ class SearchIndexUpdateDateTuple(Tuple, ACIUpdateDateTupleABC):
     __tupleType__ = searchTuplePrefix + "SearchIndexUpdateDateTuple"
 
     # Improve performance of the JSON serialisation
-    __rawJonableFields__ = ('initialLoadComplete', 'updateDateByChunkKey')
+    __rawJonableFields__ = ("initialLoadComplete", "updateDateByChunkKey")
 
     initialLoadComplete: bool = TupleField()
     updateDateByChunkKey: Dict[str, str] = TupleField({})
