@@ -12,6 +12,7 @@ import {
     TupleStorageFactoryService,
     VortexService,
     VortexStatusService,
+    TupleStorageBatchSaveArguments,
 } from "@synerty/vortexjs";
 import {
     searchFilt,
@@ -23,9 +24,9 @@ import { EncodedSearchIndexChunkTuple } from "./EncodedSearchIndexChunkTuple";
 import { SearchIndexUpdateDateTuple } from "./SearchIndexUpdateDateTuple";
 import { SearchTupleService } from "../SearchTupleService";
 import { PrivateSearchIndexLoaderStatusTuple } from "./PrivateSearchIndexLoaderStatusTuple";
-import { splitFullKeywords, splitPartialKeywords } from "../KeywordSplitter";
+
 import {
-    DeviceOfflineCacheControllerService,
+    DeviceOfflineCacheService,
     OfflineCacheStatusTuple,
 } from "@peek/peek_core_device";
 
@@ -111,7 +112,12 @@ function keywordChunk(keyword: string): string {
 @Injectable()
 export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
     private UPDATE_CHUNK_FETCH_SIZE = 5;
-    private OFFLINE_CHECK_PERIOD_MS = 15 * 60 * 1000; // 15 minutes
+
+    // Every 100 chunks from the server
+    private SAVE_POINT_ITERATIONS = 100;
+
+    // Saving the cache after each chunk is so expensive, we only do it every 20 or so
+    private chunksSavedSinceLastIndexSave = 0;
 
     private index = new SearchIndexUpdateDateTuple();
     private askServerChunks: SearchIndexUpdateDateTuple[] = [];
@@ -129,7 +135,7 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
         private vortexStatusService: VortexStatusService,
         storageFactory: TupleStorageFactoryService,
         private tupleService: SearchTupleService,
-        private deviceCacheControllerService: DeviceOfflineCacheControllerService
+        private deviceCacheControllerService: DeviceOfflineCacheService
     ) {
         super();
 
@@ -172,18 +178,16 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
      *
      */
     getObjectIds(
-        propertyName: string | null,
-        searchString: string
-    ): Promise<number[]> {
+        tokens: string[],
+        propertyName: string | null
+    ): Promise<{ [token: string]: number[] }> {
         if (this.isReady())
-            return this.getObjectIdsForSearchString(searchString, propertyName);
+            return this._getObjectIdsForTokens(tokens, propertyName);
 
         return this.isReadyObservable()
             .pipe(first())
             .toPromise()
-            .then(() =>
-                this.getObjectIdsForSearchString(searchString, propertyName)
-            );
+            .then(() => this._getObjectIdsForTokens(tokens, propertyName));
     }
 
     private _notifyStatus(): void {
@@ -245,7 +249,7 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
             )
             .pipe(takeUntil(this.onDestroyEvent))
             .subscribe((payloadEnvelope: PayloadEnvelope) => {
-                this.processSearchIndexesFromServer(payloadEnvelope);
+                this.processChunksFromServer(payloadEnvelope);
             });
 
         // If the vortex service comes back online, update the watch grids.
@@ -257,7 +261,7 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
 
     private areWeTalkingToTheServer(): boolean {
         return (
-            this.deviceCacheControllerService.cachingEnabled &&
+            this.deviceCacheControllerService.offlineModeEnabled &&
             this.vortexStatusService.snapshot.isOnline
         );
     }
@@ -342,166 +346,106 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
 
         if (this.askServerChunks.length == 0) return;
 
-        let indexChunk: SearchIndexUpdateDateTuple = this.askServerChunks.pop();
-        let filt = extend({}, clientSearchIndexWatchUpdateFromDeviceFilt);
-        filt[cacheAll] = true;
-        let pl = new Payload(filt, [indexChunk]);
-        this.vortexService.sendPayload(pl);
+        this.deviceCacheControllerService //
+            .waitForGarbageCollector()
+            .then(() => {
+                let indexChunk: SearchIndexUpdateDateTuple =
+                    this.askServerChunks.pop();
+                let filt = extend(
+                    {},
+                    clientSearchIndexWatchUpdateFromDeviceFilt
+                );
+                filt[cacheAll] = true;
+                let pl = new Payload(filt, [indexChunk]);
+                this.vortexService.sendPayload(pl);
 
-        this._status.lastCheck = new Date();
+                this._status.lastCheck = new Date();
+                this._notifyStatus();
+            });
     }
 
     /** Process SearchIndexes From Server
      *
      * Process the grids the server has sent us.
      */
-    private processSearchIndexesFromServer(payloadEnvelope: PayloadEnvelope) {
+    private async processChunksFromServer(
+        payloadEnvelope: PayloadEnvelope
+    ): Promise<void> {
         if (payloadEnvelope.result != null && payloadEnvelope.result != true) {
             console.log(`ERROR: ${payloadEnvelope.result}`);
             return;
         }
 
-        payloadEnvelope
-            .decodePayload()
-            .then((payload: Payload) => this.storeSearchIndexPayload(payload))
-            .then(() => {
-                if (this.askServerChunks.length == 0) {
-                    this.index.initialLoadComplete = true;
-                    this._hasLoaded = true;
-                    this._hasLoadedSubject.next();
-                } else if (payloadEnvelope.filt[cacheAll] == true) {
-                    this.askServerForNextUpdateChunk();
-                }
-            })
-            .then(() => this._notifyStatus())
-            .catch(
-                (e) =>
-                    `SearchIndexCache.processSearchIndexesFromServer failed: ${e}`
-            );
-    }
-
-    private storeSearchIndexPayload(payload: Payload) {
-        let tuplesToSave: EncodedSearchIndexChunkTuple[] = <
+        const tuplesToSave: EncodedSearchIndexChunkTuple[] = <
             EncodedSearchIndexChunkTuple[]
-        >payload.tuples;
-        if (tuplesToSave.length == 0) return;
+        >payloadEnvelope.data;
 
-        // 2) Store the index
-        this.storeSearchIndexChunkTuples(tuplesToSave)
-            .then(() => {
-                // 3) Store the update date
+        try {
+            await this.storeChunkTuples(tuplesToSave);
+        } catch (e) {
+            console.log(`SearchIndexCache.storeSearchIndexPayload: ${e}`);
+        }
 
-                for (let searchIndex of tuplesToSave) {
-                    this.index.updateDateByChunkKey[searchIndex.chunkKey] =
-                        searchIndex.lastUpdate;
-                }
+        if (this.askServerChunks.length == 0) {
+            this.index.initialLoadComplete = true;
+            await this.saveChunkCacheIndex(true);
+            this._hasLoaded = true;
+            this._hasLoadedSubject.next();
+        } else if (payloadEnvelope.filt[cacheAll] == true) {
+            this.askServerForNextUpdateChunk();
+        }
 
-                return this.storage.saveTuples(new UpdateDateTupleSelector(), [
-                    this.index,
-                ]);
-            })
-            .catch((e) =>
-                console.log(`SearchIndexCache.storeSearchIndexPayload: ${e}`)
-            );
+        this._notifyStatus();
     }
 
     /** Store Index Bucket
      * Stores the index bucket in the local db.
      */
-    private storeSearchIndexChunkTuples(
-        encodedSearchIndexChunkTuples: EncodedSearchIndexChunkTuple[]
+    private async storeChunkTuples(
+        tuplesToSave: EncodedSearchIndexChunkTuple[]
     ): Promise<void> {
-        let retPromise: any;
-        retPromise = this.storage.transaction(true).then((tx) => {
-            let promises = [];
+        // noinspection BadExpressionStatementJS
+        const Selector = SearchIndexChunkTupleSelector;
 
-            for (let encodedSearchIndexChunkTuple of encodedSearchIndexChunkTuples) {
-                promises.push(
-                    tx.saveTuplesEncoded(
-                        new SearchIndexChunkTupleSelector(
-                            encodedSearchIndexChunkTuple.chunkKey
-                        ),
-                        encodedSearchIndexChunkTuple.encodedData
-                    )
-                );
-            }
+        if (tuplesToSave.length == 0) return;
 
-            return Promise.all(promises).then(() => tx.close());
-        });
-        return retPromise;
+        const batchStore: TupleStorageBatchSaveArguments[] = [];
+        for (const tuple of tuplesToSave) {
+            batchStore.push({
+                tupleSelector: new Selector(tuple.chunkKey),
+                vortexMsg: tuple.encodedData,
+            });
+        }
+
+        await this.storage.batchSaveTuplesEncoded(batchStore);
+
+        for (const tuple of tuplesToSave) {
+            this.index.updateDateByChunkKey[tuple.chunkKey] = tuple.lastUpdate;
+        }
+        await this.saveChunkCacheIndex(true);
     }
 
-    /** Get Object IDs When Ready
+    /** Store Chunk Cache Index
      *
-     * Get the objects with matching keywords from the index..
+     * Updates our running tab of the update dates of the cached chunks
      *
-     * This should match FastKeywordController.py
      */
-    private async getObjectIdsForSearchString(
-        searchString: string,
-        propertyName: string | null
-    ): Promise<number[]> {
-        console.log(`Started search with string |${searchString}|`);
-
-        // ---------------
-        // Search for fulls
-        const fullKwTokens = splitFullKeywords(searchString);
-
-        console.log(`Searching for full tokens |${fullKwTokens}|`);
-
-        // If there are no tokens then return nothing
-        if (fullKwTokens == null || fullKwTokens.length == 0) {
-            return [];
+    private async saveChunkCacheIndex(force = false): Promise<void> {
+        if (
+            this.chunksSavedSinceLastIndexSave <= this.SAVE_POINT_ITERATIONS &&
+            !force
+        ) {
+            return;
         }
 
-        // First find all the results from the full kw tokens
-        const resultsByFullKw: { [token: string]: number[] } =
-            await this.loadObjectIdsFromIndex(fullKwTokens, propertyName);
+        this.chunksSavedSinceLastIndexSave = 0;
 
-        // Filter out the no matches
-        for (let token of Object.keys(resultsByFullKw)) {
-            if (resultsByFullKw[token] == null) delete resultsByFullKw[token];
-        }
-
-        // Get the remaining tokens to try the partial keyword search in
-        const remainingSearchString = fullKwTokens
-            .filter((kw) => resultsByFullKw[kw] == null)
-            .join(" ");
-
-        // Now lookup any remaining keywords, if any
-        const partialKwTokens = splitPartialKeywords(remainingSearchString);
-        const resultsByPartialKw: { [token: string]: number[] } =
-            await this.loadObjectIdsFromIndex(partialKwTokens, propertyName);
-
-        console.log("Found results for partial tokens |${resultsByPartialKw}|");
-
-        // ---------------
-        // Process the results
-
-        // Merge the results
-        const results = {};
-        Object.assign(results, resultsByFullKw);
-        Object.assign(results, resultsByPartialKw);
-
-        // If there are no results, then return
-        if (Object.keys(results).length !== 0) return [];
-
-        // Now, return the ObjectIDs that exist in all keyword lookups
-        const keys = Object.keys(results);
-
-        let objectIdsUnion: any = new Set<number>(results[keys.pop()]);
-        for (let key of keys) {
-            const thisSet = new Set<number>(results[key]);
-            objectIdsUnion = new Set<number>(
-                [...objectIdsUnion].filter((x) => thisSet.has(x))
-            );
-        }
-
-        // Limit to 50 and return
-        return [...objectIdsUnion].slice(0, 50);
+        await this.storage.saveTuples(new UpdateDateTupleSelector(), [
+            this.index,
+        ]);
     }
 
-    private async loadObjectIdsFromIndex(
+    private async _getObjectIdsForTokens(
         tokens: string[],
         propertyName: string | null
     ): Promise<{ [token: string]: number[] }> {
@@ -518,10 +462,10 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
         for (let chunkKey of Object.keys(tokensByChunkKey)) {
             const tokensInChunk = tokensByChunkKey[chunkKey];
             promises.push(
-                this.getObjectIdsForKeyword(
+                this._getObjectIdsForTokensForChunk(
+                    tokensInChunk,
                     propertyName,
-                    chunkKey,
-                    tokensInChunk
+                    chunkKey
                 )
             );
         }
@@ -540,10 +484,10 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
      * Get the objects with matching keywords from the index..
      *
      */
-    private async getObjectIdsForKeyword(
+    private async _getObjectIdsForTokensForChunk(
+        tokens: string[],
         propertyName: string | null,
-        chunkKey: string,
-        tokens: string[]
+        chunkKey: string
     ): Promise<{ [token: string]: number[] }> {
         if (tokens == null || tokens.length == 0) {
             throw new Error("We've been passed a null/empty keyword");
